@@ -48,6 +48,7 @@ class BaseBergen:
             jupyter=False,
             client_type: ClientType = ClientType.CLIENT,
             log_stream=False,
+            auto_connect=False,
             **kwargs) -> None:
         
         if jupyter:
@@ -84,7 +85,11 @@ class BaseBergen:
         self._provider = None
         self._entertainer = None
         self.negotiate_additionals = {}
-        super().__init__() 
+
+        if auto_connect:
+            self.negotiate()
+
+
 
 
     @property
@@ -193,8 +198,8 @@ class BaseBergen:
         self.identifierDataPointMap = {model.identifier.lower(): model.point for model in self._transcript.models}
         self.identifierWardMap = {model.identifier.lower(): datapoint_registry.createWardForDatapoint(model.point, self) for model in self._transcript.models}
 
-        
-        await datapoint_registry.configureWards()
+        # Negotating Extensions for the Datapoints
+        self._extensions = await datapoint_registry.configureWards()
 
         self.postman = self.getPostmanFromSettings(self._transcript)
         await self.postman.connect()
@@ -256,8 +261,7 @@ class BaseBergen:
 
     def negotiate(self):
         self.loop = asyncio.get_event_loop()
-        if self.loop.is_running():
-            raise Exception("You cannot negotiate with an already running Event loop, please ue negotiate_async")
+        assert not self.loop.is_running(), "You cannot negotiate with an already running Event loop, please ue negotiate_async"
 
         self.loop.run_until_complete(self.negotiate_async())
 
@@ -265,11 +269,12 @@ class BaseBergen:
     def getUser(self) -> User:
         return self.auth.getUser()
 
+    
+
 
     def getExtensions(self, service):
-        assert service in self._transcript.extensions, "This Service doesnt register Extensions on Negotiate"
-        assert self._transcript.extensions[service] is not None, "There are no extensions registered for this Service and this App (see negotiate)"
-        return self._transcript.extensions[service]
+        assert self._extensions[service] is not None, "There are no extensions registered for this Service and this App (see negotiate)"
+        return self._extensions[service]
     
         
     def getWard(self) -> BaseWard:
