@@ -11,6 +11,7 @@ class MessageMetaExtensionsModel(BaseModel):
 
     We wrap this in its own message to allow more"""
     progress: Optional[str]
+    persist: bool = True
 
 class MessageMetaModel(BaseModel):
     type: str
@@ -45,7 +46,6 @@ class MessageModel(BaseModel):
     def unwrapped_message(cls: Type[T], function) -> Callable[[Any], T]:
 
         async def unwrapped(self, message, *args, **kwargs):
-            print(message)
             input = cls.from_message(message)
             return await function(self, input, message, *args, **kwargs)
 
