@@ -1,12 +1,9 @@
 from pydantic.main import BaseModel
+from .params import ProvideParams
 from ....messages.types import  PROVIDE
 from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
 from typing import List, Optional
 
-class ProvideParams(BaseModel):
-    providers: Optional[List[str]]
-
-
 class ProvideMetaExtensionsModel(MessageMetaExtensionsModel):
     # Set by postman consumer
     progress: Optional[str]
@@ -17,7 +14,6 @@ class ProvideMetaModel(MessageMetaModel):
     extensions: Optional[ProvideMetaExtensionsModel]
 
 class ProvideDataModel(MessageDataModel):
-
     node: Optional[str] #TODO: Maybe not optional
     template: Optional[str]
     params: Optional[ProvideParams]
