@@ -1,5 +1,8 @@
 
-from bergen.models import Node, NodeType
+from bergen.models import Node
+from bergen.schema import NodeType
+
+
 from typing import Callable, Type
 from bergen.types.node.ports.arg import IntArgPort, ModelArgPort, StringArgPort
 from bergen.types.node.ports.kwarg import IntKwargPort, ModelKwargPort, StringKwargPort
